<template>
  <nav
    aria-label="Pagination"
    class="flex items-center justify-between"
  >
    <div class="hidden sm:block">
      <p class="text-sm text-gray-700">
        {{ $t("app.pagination.viewing") }}
        <span class="font-medium text-gray-700">{{ collection.from }}</span>
        {{ $t("app.pagination.to") }}
        <span class="font-medium text-gray-700">{{ collection.to }}</span>
        {{ $t("app.pagination.of") }}
        <span class="font-medium text-gray-700">{{ collection.total }}</span>
        {{ $t("app.pagination.results", collection.total) }}
      </p>
    </div>
    <div class="flex flex-1 justify-between space-x-3 sm:justify-end">
      <button
        :disabled="collection.current_page === 1"
        class="btn btn-white"
        type="button"
        @click="prevPage"
      >
        {{ $t("app.pagination.previous") }}
      </button>
      <button
        :disabled="!collection.has_more"
        class="btn btn-white"
        type="button"
        @click="nextPage"
      >
        {{ $t("app.pagination.next") }}
      </button>
    </div>
  </nav>
</template>

<script setup lang="ts" generic="T">
import type PaginatedCollection from "@/js/contexts/shared/models/PaginatedCollection";

const props = defineProps<{
  collection: PaginatedCollection<T>;
}>();

const emit = defineEmits<{
  changePage: [page: number | null];
}>();

const prevPage = () => {
  if (props.collection.current_page > 1) {
    const page = props.collection.current_page - 1;
    emit("changePage", page > 1 ? page : null);
  }
};
const nextPage = () => {
  if (props.collection.has_more) {
    emit("changePage", props.collection.current_page + 1);
  }
};
</script>
